@@ -19,7 +19,8 @@
 
 #include "compat.h"
 
-#if (defined(__GLIBC__) || defined(__FreeBSD__) || defined(__darwin__) || defined(__NetBSD__))
+#if (defined(__linux__) || defined(__GLIBC__) || defined(__FreeBSD__) || \
+		defined(__darwin__) || defined(__NetBSD__))
 
 /*
  * Initialize a pthread mutex. This never fails.
@@ -73,7 +74,7 @@ void tsocks_mutex_unlock(tsocks_mutex_t *m)
 
 /*
  * Call the given routine once, and only once. tsocks_once returning
- * guarantees that the routine has succeded.
+ * guarantees that the routine has succeeded.
  */
 void tsocks_once(tsocks_once_t *o, void (*init_routine)(void))
 {
@@ -96,4 +97,4 @@ void tsocks_once(tsocks_once_t *o, void (*init_routine)(void))
 	tsocks_mutex_unlock(&o->mutex);
 }
 
-#endif /* __GLIBC__, __darwin__, __FreeBSD__, __NetBSD__ */
+#endif /* __linux__, __GLIBC__, __darwin__, __FreeBSD__, __NetBSD__ */
