@@ -22,9 +22,12 @@
 #define __darwin__	1
 #endif
 
-#if (defined(__GLIBC__) || defined(__FreeBSD__) || defined(__darwin__) || defined(__NetBSD__))
+#if (defined(__linux__) || defined(__GLIBC__) || defined(__FreeBSD__) || \
+		defined(__darwin__) || defined(__NetBSD__))
 
+#ifndef RTLD_NEXT
 #define RTLD_NEXT	((void *) -1)
+#endif
 
 #include <pthread.h>
 
@@ -55,7 +58,7 @@ void tsocks_once(tsocks_once_t *o, void (*init_routine)(void));
 
 #else
 #error "OS not supported."
-#endif /* __GLIBC__, __darwin__, __FreeBSD__, __NetBSD__ */
+#endif /* __linux__, __GLIBC__, __darwin__, __FreeBSD__, __NetBSD__ */
 
 #if defined(__linux__)
 #include <unistd.h>
@@ -64,7 +67,7 @@ void tsocks_once(tsocks_once_t *o, void (*init_routine)(void));
 /*
  * Some old system requires kernel headers for those values. If they are not
  * defined, set them to a bad syscall value. Just to be clear, if the value is
- * undefined, tsocks syscall() will DENY the real syscall if catched.
+ * undefined, tsocks syscall() will DENY the real syscall if caught.
  *
  * The values are not the same per syscall here so we don't end up with
  * duplicates in the switch case in the tsocks sycall wrapper.
@@ -108,6 +111,30 @@ void tsocks_once(tsocks_once_t *o, void (*init_routine)(void));
 #ifndef __NR_accept4
 #define __NR_accept4 -13
 #endif
+#ifndef __NR_sched_getaffinity
+#define __NR_sched_getaffinity -14
+#endif
+#ifndef __NR_seccomp
+#define __NR_seccomp -15
+#endif
+#ifndef __NR_gettimeofday
+#define __NR_gettimeofday -16
+#endif
+#ifndef __NR_clock_gettime
+#define __NR_clock_gettime -17
+#endif
+#ifndef __NR_fork
+#define __NR_fork -18
+#endif
+#ifndef __NR_memfd_create
+#define __NR_memfd_create -19
+#endif
+#ifndef __NR_getdents
+#define __NR_getdents -20
+#endif
+#ifndef __NR_getdents64
+#define __NR_getdents64 -21
+#endif
 
 #define TSOCKS_NR_SOCKET    __NR_socket
 #define TSOCKS_NR_CONNECT   __NR_connect
@@ -122,6 +149,14 @@ void tsocks_once(tsocks_once_t *o, void (*init_routine)(void));
 #define TSOCKS_NR_GETRANDOM __NR_getrandom
 #define TSOCKS_NR_FUTEX     __NR_futex
 #define TSOCKS_NR_ACCEPT4   __NR_accept4
+#define TSOCKS_NR_SCHED_GETAFFINITY __NR_sched_getaffinity
+#define TSOCKS_NR_SECCOMP   __NR_seccomp
+#define TSOCKS_NR_GETTIMEOFDAY __NR_gettimeofday
+#define TSOCKS_NR_CLOCK_GETTIME __NR_clock_gettime
+#define TSOCKS_NR_FORK      __NR_fork
+#define TSOCKS_NR_MEMFD_CREATE __NR_memfd_create
+#define TSOCKS_NR_GETDENTS __NR_getdents
+#define TSOCKS_NR_GETDENTS64 __NR_getdents64
 
 /*
  * Despite glibc providing wrappers for these calls for a long time
@@ -219,9 +254,13 @@ void tsocks_once(tsocks_once_t *o, void (*init_routine)(void));
 #if defined(__NetBSD__)
 #define IS_SOCK_STREAM(type) \
 	((type & ~(SOCK_NONBLOCK | SOCK_CLOEXEC | SOCK_NOSIGPIPE)) == SOCK_STREAM)
+#define IS_SOCK_DGRAM(type) \
+	((type & ~(SOCK_NONBLOCK | SOCK_CLOEXEC | SOCK_NOSIGPIPE)) == SOCK_DGRAM)
 #else /* __NetBSD__ */
 #define IS_SOCK_STREAM(type) \
 	((type & ~(SOCK_NONBLOCK | SOCK_CLOEXEC)) == SOCK_STREAM)
+#define IS_SOCK_DGRAM(type) \
+	((type & ~(SOCK_NONBLOCK | SOCK_CLOEXEC)) == SOCK_DGRAM)
 #endif /* __NetBSD__ */
 
 #endif /* TORSOCKS_COMPAT_H */
