@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2008 - Shaun Clowes <delius@progsoc.org> 
+ * Copyright (C) 2000-2008 - Shaun Clowes <delius@progsoc.org>
  * 				 2008-2011 - Robert Hogan <robert@roberthogan.net>
  * 				 	  2013 - David Goulet <dgoulet@ev0ke.net>
  *
@@ -40,6 +40,7 @@ static const char *conf_socks5_pass_str = "SOCKS5Password";
 static const char *conf_allow_inbound_str = "AllowInbound";
 static const char *conf_allow_outbound_localhost_str = "AllowOutboundLocalhost";
 static const char *conf_isolate_pid_str = "IsolatePID";
+static const char *conf_enable_ipv6_str = "EnableIPv6";
 
 /*
  * Once this value reaches 2, it means both user and password for a SOCKS5
@@ -115,76 +116,7 @@ error:
 }
 
 /*
- * Set the given string port in a configuration object.
- *
- * Return 0 on success or else a negative EINVAL if the port is equal to 0 or
- * over 65535.
- */
-static int set_tor_port(const char *port, struct configuration *config)
-{
-	int ret = 0;
-	char *endptr;
-	unsigned long _port;
-
-	assert(port);
-	assert(config);
-
-	/* Let's avoid a integer overflow here ;). */
-	_port = strtoul(port, &endptr, 10);
-	if (_port == 0 || _port > 65535) {
-		ret = -EINVAL;
-		ERR("Config file invalid port: %s", port);
-		goto error;
-	}
-
-	config->conf_file.tor_port = (in_port_t) _port;
-
-	DBG("Config file setting tor port to %lu", _port);
-
-error:
-	return ret;
-}
-
-/*
- * Set the given string address in a configuration object.
- *
- * Return 0 on success or else a negative value. On error, the address was not
- * recognized.
- */
-static int set_tor_address(const char *addr, struct configuration *config)
-{
-	int ret;
-
-	assert(addr);
-	assert(config);
-
-	ret = utils_is_address_ipv4(addr);
-	if (ret == 1 ) {
-		config->conf_file.tor_domain = CONNECTION_DOMAIN_INET;
-	} else {
-		ret = utils_is_address_ipv6(addr);
-		if (ret != 1) {
-			/* At this point, the addr is either v4 nor v6 so error. */
-			ERR("Config file unknown tor address: %s", addr);
-			goto error;
-		}
-		config->conf_file.tor_domain = CONNECTION_DOMAIN_INET6;
-	}
-	config->conf_file.tor_address = strdup(addr);
-	if (!config->conf_file.tor_address) {
-		ret = -ENOMEM;
-		goto error;
-	}
-
-	DBG("Config file setting tor address to %s", addr);
-	ret = 0;
-
-error:
-	return ret;
-}
-
-/*
- * Parse a single line of from a configuration file and set the value found in
+ * Parse a single line from a configuration file and set the value found in
  * the configuration object.
  *
  * Return 0 on success or else a negative value.
@@ -200,7 +132,8 @@ static int parse_config_line(const char *line, struct configuration *config)
 	/*
 	 * The line is tokenized and each token is NULL terminated.
 	 */
-	nb_token = utils_tokenize_ignore_comments(line, sizeof(tokens), tokens);
+	nb_token = utils_tokenize_ignore_comments(line, DEFAULT_MAX_CONF_TOKEN,
+			tokens);
 	if (nb_token <= 0) {
 		/* Nothing on this line that is useful to parse. */
 		ret = 0;
@@ -208,12 +141,12 @@ static int parse_config_line(const char *line, struct configuration *config)
 	}
 
 	if (!strcmp(tokens[0], conf_toraddr_str)) {
-		ret = set_tor_address(tokens[1], config);
+		ret = conf_file_set_tor_address(tokens[1], config);
 		if (ret < 0) {
 			goto error;
 		}
 	} else if (!strcmp(tokens[0], conf_torport_str)) {
-		ret = set_tor_port(tokens[1], config);
+		ret = conf_file_set_tor_port(tokens[1], config);
 		if (ret < 0) {
 			goto error;
 		}
@@ -247,6 +180,11 @@ static int parse_config_line(const char *line, struct configuration *config)
 		if (ret < 0) {
 			goto error;
 		}
+	} else if (!strcmp(tokens[0], conf_enable_ipv6_str)) {
+		ret = conf_file_set_enable_ipv6(tokens[1], config);
+		if (ret < 0) {
+			goto error;
+		}
 	} else {
 		WARN("Config file contains unknown value: %s", line);
 	}
@@ -293,6 +231,83 @@ error:
 	return ret;
 }
 
+/*
+ * Set the given string port in a configuration object.
+ *
+ * Return 0 on success or else a negative EINVAL if the port is equal to 0 or
+ * over 65535.
+ */
+ATTR_HIDDEN
+int conf_file_set_tor_port(const char *port, struct configuration *config)
+{
+	int ret = 0;
+	char *endptr;
+	unsigned long _port;
+
+	assert(port);
+	assert(config);
+
+	/* Let's avoid an integer overflow here ;). */
+	_port = strtoul(port, &endptr, 10);
+	if (_port == 0 || _port > 65535) {
+		ret = -EINVAL;
+		ERR("Config file invalid port: %s", port);
+		goto error;
+	}
+
+	config->conf_file.tor_port = (in_port_t) _port;
+
+	DBG("Config file setting tor port to %lu", _port);
+
+error:
+	return ret;
+}
+
+/*
+ * Set the given string address in a configuration object.
+ *
+ * Return 0 on success or else a negative value. On error, the address was not
+ * recognized.
+ */
+ATTR_HIDDEN
+int conf_file_set_tor_address(const char *addr, struct configuration *config)
+{
+	int ret;
+
+	assert(addr);
+	assert(config);
+
+	ret = utils_is_address_ipv4(addr);
+	if (ret == 1 ) {
+		config->conf_file.tor_domain = CONNECTION_DOMAIN_INET;
+	} else {
+		ret = utils_is_address_ipv6(addr);
+		if (ret != 1) {
+			/* At this point, the addr is either v4 nor v6 so error. */
+			ERR("Config file unknown tor address: %s", addr);
+			goto error;
+		}
+		config->conf_file.tor_domain = CONNECTION_DOMAIN_INET6;
+	}
+
+	if (config->conf_file.tor_address != NULL) {
+		free(config->conf_file.tor_address);
+		config->conf_file.tor_address = NULL;
+	}
+
+	config->conf_file.tor_address = strdup(addr);
+	if (config->conf_file.tor_address == NULL) {
+		ret = -ENOMEM;
+		goto error;
+	}
+
+	DBG("Config file setting tor address to %s", addr);
+	ret = 0;
+
+error:
+	return ret;
+}
+
 /*
  * Set the SOCKS5 username to the given configuration.
  *
@@ -406,6 +421,9 @@ int conf_file_set_allow_outbound_localhost(const char *val,
 	} else if (ret == 1) {
 		config->allow_outbound_localhost = 1;
 		DBG("[config] Outbound localhost connections allowed.");
+	} else if (ret == 2) {
+		config->allow_outbound_localhost = 2;
+		DBG("[config] Outbound localhost connections + UDP allowed.");
 	} else {
 		ERR("[config] Invalid %s value for %s", val,
 				conf_allow_outbound_localhost_str);
@@ -444,6 +462,35 @@ int conf_file_set_isolate_pid(const char *val, struct configuration *config)
 	return ret;
 }
 
+/*
+ * Set the enable_ipv6 option for the given config.
+ *
+ * Return 0 if option is off, 1 if on and negative value on error.
+ */
+ATTR_HIDDEN
+int conf_file_set_enable_ipv6(const char *val, struct configuration *config)
+{
+	int ret;
+
+	assert(val);
+	assert(config);
+
+	ret = atoi(val);
+	if (ret == 0) {
+		config->enable_ipv6 = 0;
+		DBG("[config] PID isolation disabled.");
+	} else if (ret == 1) {
+		config->enable_ipv6 = 1;
+		DBG("[config] PID isolation enabled.");
+	} else {
+		ERR("[config] Invalid %s value for %s", val,
+				conf_enable_ipv6_str);
+		ret = -EINVAL;
+	}
+
+	return ret;
+}
+
 /*
  * Applies the SOCKS authentication configuration and sets the final SOCKS
  * username and password.
@@ -534,12 +581,12 @@ int config_file_read(const char *filename, struct configuration *config)
 	fp = fopen(filename, "r");
 	if (!fp) {
 		WARN("Config file not found: %s. Using default for Tor", filename);
-		(void) set_tor_address(DEFAULT_TOR_ADDRESS, config);
+		(void) conf_file_set_tor_address(DEFAULT_TOR_ADDRESS, config);
 		/*
 		 * We stringify the default value here so we can print the debug
 		 * statement in the function call to set port.
 		 */
-		(void) set_tor_port(XSTR(DEFAULT_TOR_PORT), config);
+		(void) conf_file_set_tor_port(XSTR(DEFAULT_TOR_PORT), config);
 
 		ret = set_onion_info(
 				DEFAULT_ONION_ADDR_RANGE "/" DEFAULT_ONION_ADDR_MASK, config);
@@ -569,7 +616,7 @@ error:
 
 /*
  * Free everything inside a configuration file object. It is the caller
- * responsability to free the object if needed.
+ * responsibility to free the object if needed.
  */
 ATTR_HIDDEN
 void config_file_destroy(struct config_file *conf)
