@@ -82,7 +82,7 @@ struct configuration {
 	/*
 	 * Allow outbound connections to localhost that bypass Tor.
 	 */
-	unsigned int allow_outbound_localhost:1;
+	unsigned int allow_outbound_localhost;
 
 	/*
 	 * Automatically set the SOCKS5 authentication to a unique per-process
@@ -90,10 +90,17 @@ struct configuration {
 	 * username or password.
 	 */
 	unsigned int isolate_pid:1;
+
+	/*
+	 * Enable IPv6.
+	 */
+	unsigned int enable_ipv6:1;
 };
 
 int config_file_read(const char *filename, struct configuration *config);
 void config_file_destroy(struct config_file *conf);
+int conf_file_set_tor_address(const char *addr, struct configuration *config);
+int conf_file_set_tor_port(const char *port, struct configuration *config);
 int conf_file_set_socks5_pass(const char *password,
 		struct configuration *config);
 int conf_file_set_socks5_user(const char *username,
