@@ -33,7 +33,7 @@
 #define DEFAULT_LOG_LEVEL			MSGWARN
 
 /*
- * RFC 1035 specifies a maxium of 255 possibe for domain name.
+ * RFC 1035 specifies a maximum of 255 possible for domain name.
  * (https://www.ietf.org/rfc/rfc1035.txt).
  */
 #define DEFAULT_DOMAIN_NAME_SIZE	255
@@ -63,10 +63,17 @@
 #define DEFAULT_SOCKS5_USER_ENV     "TORSOCKS_USERNAME"
 #define DEFAULT_SOCKS5_PASS_ENV     "TORSOCKS_PASSWORD"
 
+/* Env. variable for Tor hostname and port. */
+#define DEFAULT_TOR_ADDRESS_ENV     "TORSOCKS_TOR_ADDRESS"
+#define DEFAULT_TOR_PORT_ENV        "TORSOCKS_TOR_PORT"
+
 /* Control if torsocks allows inbound connection or not. */
 #define DEFAULT_ALLOW_INBOUND_ENV   "TORSOCKS_ALLOW_INBOUND"
 
 /* Control if torsocks isolates based on PID or not. */
 #define DEFAULT_ISOLATE_PID_ENV     "TORSOCKS_ISOLATE_PID"
 
+/* Control if torsocks supports IPv6 sockets or not. */
+#define DEFAULT_ENABLE_IPV6_ENV     "TORSOCKS_ENABLE_IPV6"
+
 #endif /* TORSOCKS_DEFAULTS_H */
