@@ -32,6 +32,12 @@ LIBC_SOCKET_RET_TYPE tsocks_socket(LIBC_SOCKET_SIG)
 	DBG("[socket] Creating socket with domain %d, type %d and protocol %d",
 			domain, type, protocol);
 
+	if (domain == AF_INET6 && !tsocks_config.enable_ipv6) {
+		DBG("[socket] Denying ipv6");
+		errno = ENOSYS;
+		return -1;
+	}
+
 	if (IS_SOCK_STREAM(type)) {
 		/*
 		 * The socket family is not checked here since we accept local socket
@@ -47,12 +53,22 @@ LIBC_SOCKET_RET_TYPE tsocks_socket(LIBC_SOCKET_SIG)
 			goto end;
 		}
 
+		/*
+		 * If outbound localhost UDP traffic is allowed, then allow all UDP
+		 * socket creation.  Validation on the destination addr is done at
+		 * connect()/sendto() time.
+		 */
+		if ((tsocks_config.allow_outbound_localhost == 2) &&
+				IS_SOCK_DGRAM(type)) {
+			goto end;
+		}
+
 		/*
 		 * Print this message only in debug mode. Very often, applications uses
 		 * the libc to do DNS resolution which first tries with UDP and then
 		 * with TCP. It's not critical for the user to know that a non TCP
 		 * socket has been denied and since the libc has a fallback that works,
-		 * this message most of the time, simply polutes the application's
+		 * this message most of the time, simply pollutes the application's
 		 * output which can cause issues with external applications parsing the
 		 * output.
 		 */
