@@ -84,7 +84,7 @@ static LIBC_ACCEPT_RET_TYPE handle_accept(va_list args)
 	return tsocks_accept(sockfd, addr, &addrlen);
 }
 
-#if (defined(__linux__) || defined(__darwin__) || (defined(__FreeBSD_kernel__) && defined(__i386__)) || defined(__NetBSD__))
+#if !((defined(__NetBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)) && defined(__x86_64))
 /*
  * Handle mmap(2) syscall.
  */
@@ -104,7 +104,7 @@ static LIBC_SYSCALL_RET_TYPE handle_mmap(va_list args)
 
 	return (LIBC_SYSCALL_RET_TYPE) mmap(addr, len, prot, flags, fd, offset);
 }
-#endif /* __linux__, __darwin__, __FreeBSD_kernel__, __i386__, __NetBSD__ */
+#endif /* __NetBSD__, __FreeBSD__, __FreeBSD_kernel__, __x86_64 */
 
 /*
  * Handle munmap(2) syscall.
@@ -165,6 +165,26 @@ static LIBC_RECVMSG_RET_TYPE handle_recvmsg(va_list args)
 }
 
 #if defined(__linux__)
+
+/*
+ * Handle sched_getaffinity(2) syscall.
+ * NOTE: ffmpeg is one of the application that needs this one on the
+ * whitelist.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_sched_getaffinity(va_list args)
+{
+	pid_t pid;
+	size_t cpusetsize;
+	cpu_set_t *mask;
+
+	pid = va_arg(args, __typeof__(pid));
+	cpusetsize = va_arg(args, __typeof__(cpusetsize));
+	mask = va_arg(args, __typeof__(mask));
+
+	return tsocks_libc_syscall(TSOCKS_NR_SCHED_GETAFFINITY, pid, cpusetsize,
+			mask);
+}
+
 /*
  * Handle gettid(2) syscall.
  */
@@ -352,8 +372,114 @@ static LIBC_SYSCALL_RET_TYPE handle_inotify_rm_watch(va_list args)
 
 	return inotify_rm_watch(fd, wd);
 }
+
+/*
+ * Handle seccomp(2) syscall.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_seccomp(va_list args)
+{
+	unsigned int operation, flags;
+	void *sargs;
+
+	operation = va_arg(args, __typeof__(operation));
+	flags = va_arg(args, __typeof__(flags));
+	sargs = va_arg(args, __typeof__(sargs));
+
+	return tsocks_libc_syscall(TSOCKS_NR_SECCOMP, operation, flags, sargs);
+}
+
+/*
+ * Handle gettimeofday(2) syscall.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_gettimeofday(va_list args)
+{
+	struct timeval *tv;
+	struct timezone *tz;
+
+	tv = va_arg(args, __typeof__(tv));
+	tz = va_arg(args, __typeof__(tz));
+
+	return tsocks_libc_syscall(TSOCKS_NR_GETTIMEOFDAY, tv, tz);
+}
+
+/*
+ * Handle clock_gettime(2) syscall.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_clock_gettime(va_list args)
+{
+	clockid_t clk_id;
+	struct timespec *tp;
+
+	clk_id = va_arg(args, __typeof__(clk_id));
+	tp = va_arg(args, __typeof__(tp));
+
+	return tsocks_libc_syscall(TSOCKS_NR_CLOCK_GETTIME, clk_id, tp);
+}
+
+/*
+ * Handle fork(2) syscall.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_fork(void)
+{
+	return tsocks_libc_syscall(TSOCKS_NR_FORK);
+}
+
+/*
+ * Handle memfd_create(2) syscall.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_memfd_create(va_list args)
+{
+	const char *name;
+	unsigned int flags;
+
+	name = va_arg(args, __typeof__(name));
+	flags = va_arg(args, __typeof__(flags));
+
+	return tsocks_libc_syscall(TSOCKS_NR_MEMFD_CREATE, name, flags);
+}
+/*
+ * Handle getdents(2) syscall.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_getdents(va_list args)
+{
+	unsigned int fd;
+	struct linux_dirent *dirp;
+	unsigned int count;
+
+	fd = va_arg(args, __typeof__(fd));
+	dirp = va_arg(args, __typeof__(dirp));
+	count = va_arg(args, __typeof__(count));
+
+	return tsocks_libc_syscall(TSOCKS_NR_GETDENTS, fd, dirp, count);
+}
+/*
+ * Handle getdents64(2) syscall.
+ */
+static LIBC_SYSCALL_RET_TYPE handle_getdents64(va_list args)
+{
+	unsigned int fd;
+	struct linux_dirent64 *dirp;
+	unsigned int count;
+
+	fd = va_arg(args, __typeof__(fd));
+	dirp = va_arg(args, __typeof__(dirp));
+	count = va_arg(args, __typeof__(count));
+
+	return tsocks_libc_syscall(TSOCKS_NR_GETDENTS64, fd, dirp, count);
+}
+
 #endif /* __linux__ */
 
+static LIBC_SYSCALL_RET_TYPE handle_passthrough(long n, va_list args) {
+	long arg1 = va_arg(args, long);
+	long arg2 = va_arg(args, long);
+	long arg3 = va_arg(args, long);
+	long arg4 = va_arg(args, long);
+	long arg5 = va_arg(args, long);
+	long arg6 = va_arg(args, long);
+	return tsocks_libc_syscall(n, arg1, arg2, arg3, arg4, arg5, arg6);
+}
+
 /*
  * Torsocks call for syscall(2)
  */
@@ -455,16 +581,35 @@ LIBC_SYSCALL_RET_TYPE tsocks_syscall(long int number, va_list args)
 	case TSOCKS_NR_INOTIFY_RM_WATCH:
 		ret = handle_inotify_rm_watch(args);
 		break;
+	case TSOCKS_NR_SCHED_GETAFFINITY:
+		ret = handle_sched_getaffinity(args);
+		break;
+	case TSOCKS_NR_SECCOMP:
+		ret = handle_seccomp(args);
+		break;
+	case TSOCKS_NR_GETTIMEOFDAY:
+		ret = handle_gettimeofday(args);
+		break;
+	case TSOCKS_NR_CLOCK_GETTIME:
+		ret = handle_clock_gettime(args);
+		break;
+	case TSOCKS_NR_FORK:
+		ret = handle_fork();
+		break;
+	case TSOCKS_NR_MEMFD_CREATE:
+		ret = handle_memfd_create(args);
+		break;
+	case TSOCKS_NR_GETDENTS:
+		ret = handle_getdents(args);
+		break;
+	case TSOCKS_NR_GETDENTS64:
+		ret = handle_getdents64(args);
+		break;
 #endif /* __linux__ */
 	default:
-		/*
-		 * Because of the design of syscall(), we can't pass a va_list to it so
-		 * we are constraint to use a whitelist scheme and denying the rest.
-		 */
-		WARN("[syscall] Unsupported syscall number %ld. Denying the call",
+		DBG("[syscall] Unsupported __syscall number %ld. Passing through",
 				number);
-		ret = -1;
-		errno = ENOSYS;
+		ret = handle_passthrough(number, args);
 		break;
 	}
 
