@@ -24,8 +24,9 @@
 #include <lib/torsocks.h>
 
 #include <tap/tap.h>
+#include "helpers.h"
 
-#define NUM_TESTS 4
+#define NUM_TESTS 6
 
 struct test_host {
 	const char *name;
@@ -34,8 +35,8 @@ struct test_host {
 
 /* Tor check hostname/ip. */
 static const struct test_host tor_check = {
-	.name = "sergii.torproject.org",
-	.ip = "38.229.72.22",
+	.name = "perdulce.torproject.org",
+	.ip = "138.201.14.203",
 };
 
 /* moria1 directory authority. */
@@ -46,7 +47,7 @@ static const struct test_host tor_dir_auth1 = {
 
 /* maatuska directory authority. */
 static const struct test_host tor_dir_auth2 = {
-	.name = "ehlo.4711.se",
+	.name = "maatuska.4711.se",
 	.ip = "171.25.193.9",
 };
 
@@ -75,26 +76,77 @@ static void test_gethostbyname(const struct test_host *host)
 	return;
 }
 
+static void test_gethostbyaddr_r_failed(void)
+{
+	int result;
+	in_addr_t addr;
+	struct hostent ret;
+	char buf[1024];
+	int buflen = sizeof buf;
+	struct hostent *result_entp;
+	int h_errno;
+
+	diag("gethostbyaddr_r test");
+
+	/* RFC 6890 - An address from TEST-NET-1.  Selected in hopes that it will
+		 +   * _not_ reverse resolve to anything.
+		 +   */
+	addr = inet_addr("192.0.2.1");
+	result = gethostbyaddr_r((const void *)&addr,
+				INET_ADDRSTRLEN, AF_INET, &ret, buf, buflen, &result_entp, &h_errno);
+	ok(0 != result, "Impossible reverse resolve failed as desired.");
+}
+
+static void test_gethostbyaddr_r(const struct test_host *host)
+{
+  int result;
+  in_addr_t addr;
+  struct hostent ret;
+  char buf[1024];
+  int buflen = sizeof buf;
+  struct hostent *result_entp;
+  int h_errno;
+
+  assert(host);
+  diag("gethostbyaddr_r test");
+
+  addr = inet_addr(host->ip);
+	result = gethostbyaddr_r((const void *)&addr,
+				INET_ADDRSTRLEN, AF_INET, &ret, buf, buflen, &result_entp, &h_errno);
+
+  if (result) {
+    fail("Resolving address %s: %d", host->ip, result);
+  }
+
+  if (strcmp(host->name, result_entp->h_name) != 0) {
+    fail("Wrong resolved name: %s", result_entp->h_name);
+  }
+
+  if (result_entp->h_addrtype != AF_INET) {
+    fail("Wrong resolved address family: %d", result_entp->h_addrtype);
+  }
+
+  ok(1, "Resolved address");
+}
+
 static void test_gethostbyaddr(const struct test_host *host)
 {
 	struct hostent *he;
-    in_addr_t addr;
+  in_addr_t addr;
 
 	assert(host);
 
 	diag("gethostbyaddr test");
 
-    addr = inet_addr(host->ip);
-
-    he = gethostbyaddr(&addr, INET_ADDRSTRLEN, AF_INET);
-    if (he) {
-		ok(strcmp(host->name, he->h_name) == 0,
-				"Resolving address %s", host->ip);
-    } else {
+	addr = inet_addr(host->ip);
+	he = gethostbyaddr((const void *)&addr, INET_ADDRSTRLEN, AF_INET);
+	if (he) {
+		ok(strcmp(host->name, he->h_name) == 0, "Resolving address %s", host->ip);
+	} else {
 		fail("Resolving address %s", host->ip);
 	}
 
-    return;
+	return;
 }
 
 static void test_getaddrinfo(const struct test_host *host)
@@ -135,13 +187,22 @@ static void test_getaddrinfo(const struct test_host *host)
 
 int main(int argc, char **argv)
 {
+	/* Try to connect to SocksPort localhost:9050 and if we can't skip. This is
+	 * to avoid to have failing test if no tor daemon is available. */
+	if (!helper_is_default_tor_running()) {
+		goto end;
+	}
+
 	/* Libtap call for the number of tests planned. */
 	plan_tests(NUM_TESTS);
 
 	test_getaddrinfo(&tor_check);
-    test_gethostbyname(&tor_dir_auth1);
+	test_gethostbyname(&tor_dir_auth1);
 	test_gethostbyaddr(&tor_dir_auth2);
+	test_gethostbyaddr_r(&tor_dir_auth2);
+	test_gethostbyaddr_r_failed();
 	test_getaddrinfo(&tor_localhost);
 
-    return 0;
+end:
+	return 0;
 }
